@@ -1,3 +1,5 @@
+import os
+import pathlib
 import logging
 from fgp.controller.client import Client
 from fgp.controller.store import Store
@@ -6,6 +8,8 @@ from fgp.controller.event import Event
 from fgp.controller import ApiClient
 from fgp.cli import cli
 
+with open(os.path.join(pathlib.Path(__file__).parent.absolute(), 'VERSION.txt')) as version_file:
+    __version__ = version_file.read().strip()
 
 if __name__ == 'fgp':
     # create logger
