@@ -4,6 +4,7 @@ from .reference import Reference
 from .event import Event
 from .extension import Extension
 from .relation import Relation
+from .lambdas import Lambdas
 
 class ApiClient:
     _client: Client = None
@@ -13,6 +14,7 @@ class ApiClient:
     event: Event = None
     extension: Extension = None
     relation: Relation = None
+    lambdas: Lambdas
 
     def __init__(self, url, application, headers=None):
         self._client = Client(url, application, headers=headers)
@@ -21,3 +23,4 @@ class ApiClient:
         self.event = Event(self._client)
         self.extension = Extension(self._client)
         self.relation = Relation(self._client)
+        self.lambdas = Lambdas(self._client)
